==> pt_dev_utils-1.0.0.tar.gz: pt_dev_utils-1.0.0/pt_dev_utility/pt_csv.py <==
# Compatible with Python 2.7 and Python 3.x
from __future__ import print_function, division, absolute_import

"""CSV data processing utilities with pandas integration.

This module provides functions for reading and processing CSV files
with flexible column selection, compatible with both Python 2.7 and 3.x.
"""

import pandas as pd


def read_csv_as_dict_list(csv_file_path, custom_headers=None,
                          selected_columns=None):
    # type: (str, list, list) -> list
    """Read CSV file and return selected columns as list of dictionaries.
    
    This function provides flexible CSV reading with options for custom
    headers and column selection, returning data in a dictionary format
    suitable for further processing.
    
    Args:
        csv_file_path: Path to the CSV file to be read.
        custom_headers: Custom column names to use instead of CSV headers.
                       If None, uses the first row of CSV as headers.
        selected_columns: List of column names to include in output.
                         If None, includes all columns.
                         
    Returns:
        List of dictionaries where each dictionary represents a row
        with column names as keys.
        
    Raises:
        FileNotFoundError: If the specified CSV file does not exist.
        KeyError: If selected_columns contains non-existent column names.
        pandas.errors.EmptyDataError: If the CSV file is empty.
        
    Example:
        # Read all columns with default headers
        data = read_csv_as_dict_list('data.csv')
        
        # Read with custom headers and selected columns
        data = read_csv_as_dict_list(
            'data.csv',
            custom_headers=['name', 'age', 'city'],
            selected_columns=['name', 'age']
        )
    """
    try:
        # Load CSV with appropriate header handling
        if custom_headers is None:
            # Use CSV's first row as headers
            data_frame = pd.read_csv(csv_file_path)
        else:
            # Use custom headers and skip first row
            data_frame = pd.read_csv(
                csv_file_path,
                header=None,
                names=custom_headers,
                skiprows=1
            )
        
        # Filter columns if specified
        if selected_columns:
            data_frame = data_frame[selected_columns]
        
        # Convert to list of dictionaries
        return data_frame.to_dict(orient='records')
        
    except Exception as e:
        # Re-raise with more context for debugging
        raise Exception('Failed to read CSV file {}: {}'.format(
            csv_file_path, str(e)))


# Legacy function alias for backward compatibility
read_data_from_csv = read_csv_as_dict_list  # Deprecated

==> pt_dev_utils-1.1.8.tar.gz: pt_dev_utils-1.1.8/pt_dev_utility/pt_csv.py <==
"""CSV data processing utilities with pandas integration.

This module provides functions for reading and processing CSV files
with flexible column selection for Python 3.8+.
"""

from typing import Dict, List, Optional, Any

import pandas as pd


def read_csv_as_dict_list(
    csv_file_path: str,
    custom_headers: Optional[List[str]] = None,
    selected_columns: Optional[List[str]] = None
) -> List[Dict[str, Any]]:
    """Read CSV file and return selected columns as list of dictionaries.

    This function provides flexible CSV reading with options for custom
    headers and column selection, returning data in a dictionary format
    suitable for further processing.

    Args:
        csv_file_path: Path to the CSV file to be read.
        custom_headers: Custom column names to use instead of CSV headers.
            If None, uses the first row of the CSV as headers.
        selected_columns: List of column names to include in output.
            If None, includes all columns.

    Returns:
        List of dictionaries where each dictionary represents a row
        with column names as keys.

    Raises:
        Exception: If CSV loading or processing fails.

    Example:
        >>> # Read all columns with default headers
        >>> data = read_csv_as_dict_list('data.csv')

        >>> # Read with custom headers and selected columns
        >>> data = read_csv_as_dict_list(
        ...     'data.csv',
        ...     custom_headers=['name', 'age', 'city'],
        ...     selected_columns=['name', 'age']
        ... )
    """
    try:
        # Load CSV with appropriate header handling
        if custom_headers is None:
            # Use CSV's first row as headers
            data_frame = pd.read_csv(csv_file_path)
        else:
            # Use custom headers and skip first row
            data_frame = pd.read_csv(
                csv_file_path,
                header=None,
                names=custom_headers
            )
        
        # Filter columns if specified
        if selected_columns:
            data_frame = data_frame[selected_columns]

        # Convert to list of dictionaries
        return data_frame.to_dict(orient='records')

    except Exception as e:
        # Re-raise with more context for debugging
        raise Exception(f'Failed to read CSV file {csv_file_path}: {e}')
